@@ -26,7 +26,7 @@ class SteppingAction(G4UserSteppingAction):
     #Ekin1 = pre_step_point.GetKineticEnergy()/GeV
     Etot2 = post_step_point.GetTotalEnergy()/GeV
     #Ekin2 = post_step_point.GetKineticEnergy()/GeV
-    # Save every track point 
-    if Etot1 > self.app.E_skip_min and Etot1 > 0.76e-3:
+    # Save every track point
+    if Etot1 > self.app.E_skip_min and Etot1 > 0.76e-3 and position.z > 0.:
       # keep step end point
-      self.data_buffer.AddTrackPoint(uid, pdgid, position.x, position.y, position.z, time, Etot2)    
+      self.data_buffer.AddTrackPoint(uid, pdgid, position.x, position.y, position.z, time, Etot2)
