@@ -16,7 +16,7 @@ from g4camp.DataBuffer import DataBuffer
 
 class g4camp:
 
-    def __init__(self, optics=True, primary_generator="gun", gun_args={},
+    def __init__(self, physics="Custom", optics=True, primary_generator="gun", gun_args={},
                  multithread=False, thread_num=4):
         # By some reason multithread mode does not faster than serial mode
         # FIXME: number of threads can not be configured from here (why???)
@@ -34,8 +34,8 @@ class g4camp:
         #
         self.ph_suppression_factor = 10 # must be integer
         self.skip_mode = 'fraction'     # 'fraction' (relative to E_init) or 'GeV' (absolute)
-        self.skip_min = 1.e-3           # min energy to skip particle (wrt. E_init or in GeV)
-        self.skip_max = 1.e-1           # max energy to skip particle (wrt. E_init or in GeV)
+        self.skip_min = 0.              # min energy to skip particle (wrt. E_init or in GeV)
+        self.skip_max = 1.e-2           # max energy to skip particle (wrt. E_init or in GeV)
         self.random_seed = 1
         self.det_height_m = 1500        # detector volume: cylinder height
         self.det_radius_m = 1500        # detector volume: cylinder radius
@@ -44,6 +44,10 @@ class g4camp:
         self.E_skip_max = None          # max particle energy to skip
         self.E_init = None              # initial kinetic energy in GeV
         #
+        self.physListOptions = {"FTFP_BERT": FTFP_BERT,
+                                "QGSP_BERT": QGSP_BERT,
+                                "QGSP_BIC": QGSP_BIC}
+        #
         self.ph_counter = None
         #
         if multithread:
@@ -51,19 +55,25 @@ class g4camp:
         else:
             self.runManager = G4RunManagerFactory.CreateRunManager(G4RunManagerType.Serial)
         self.detConstruction = DetectorConstruction()
-        self.physList = CustomPhysicsList(optics=self.optics)
+        if physics == "Custom": 
+            self.physList = CustomPhysicsList(optics=self.optics)
+        else:
+            self.physList = self.physListOptions[physics]()
+            if self.optics :
+                self.log.error("Optics is only available with 'Custom' physics list")
+                sys.exit()
         self.actInit = ActionInitialization(self, primary_generator=self.primary_generator, 
                                                   gun_args=gun_args)
         self.runManager.SetUserInitialization(self.detConstruction)
         self.runManager.SetUserInitialization(self.physList)
         self.runManager.SetUserInitialization(self.actInit)
         #
+        self.setVerbose()
         self.setDefaultCuts()
 
 
     def configure(self):
         #self.actInit.stackingAction.SetPhotonSuppressionFactor(1./self.ph_fraction)
-        self.setVerbose()
         if self.multithread: 
             UImanager.ApplyCommand(f"/run/numberOfThreads", [self.thread_num])
         if self.optics:
@@ -71,16 +81,21 @@ class g4camp:
         self.detConstruction.SetHeight(self.det_height_m)
         self.detConstruction.SetRadius(self.det_radius_m)
         self.runManager.Initialize()
-        self.applyGeant4Command("/run/particle/dumpCutValues")
+        #self.applyGeant4Command("/run/particle/dumpCutValues")
         if self.primary_generator == 'gps':
             self.applyGeant4Command("/control/execute", [self.gps_macro])
         G4Random.setTheSeed(self.random_seed)
 
-    def setVerbose(self, control_verbose=0, tracking_verbose=0, run_verbose=0, em_process_verbose=0):
+    def setVerbose(self, control_verbose=0, tracking_verbose=0, run_verbose=0, 
+                   em_process_verbose=0, had_process_verbose=0):
         self.applyGeant4Command("/control/verbose", [control_verbose])
         self.applyGeant4Command("/tracking/verbose", [tracking_verbose])
         self.applyGeant4Command("/run/verbose", [run_verbose])
         self.applyGeant4Command("/process/em/verbose", [em_process_verbose])
+        self.applyGeant4Command("/process/had/verbose", [had_process_verbose])
+        self.applyGeant4Command("/process/eLoss/verbose 0")
+        self.applyGeant4Command("/particle/verbose 0")
+        self.applyGeant4Command("/cuts/verbose 0")
 
     def setCut(self, particle, cut_value, cut_unit):
         # to be invoked before 'configure()'
@@ -100,7 +115,7 @@ class g4camp:
             arg_string += f" {arg}"
         UImanager = G4UImanager.GetUIpointer()
         UImanager.ApplyCommand(command + arg_string)
-        print(command + arg_string)
+        #print(command + arg_string)
 
     def configureOptics(self):
         if not self.optics:
@@ -143,7 +158,7 @@ class g4camp:
     def setDetectorHeight(self, val):
         self.det_height_m = val
 
-    def setDetectorRaduis(self, val):
+    def setDetectorRadius(self, val):
         self.det_radius_m = val
 
     def run(self, n_events):
