@@ -25,8 +25,13 @@ def parse_arguments():
     p = configargparse.get_argument_parser()
     p.add_argument('-n', default=2, help="number of events")
     p.add_argument('-o', default='output.h5', help="output file name")
+    p.add_argument('--physics', default='Custom', help="choose physics list", choices=['Custom', 'FTFP_BERT', 'QGSP_BERT', 'QGSP_BIC'])
     p.add_argument('--enable_optics', help="enable optics", action='store_true')
     p.add_argument('-p', '--primary-generator', default='gun', choices=('gun', 'gps'), help="type of primary generator type")
+    p.add_argument('--gun_particle', default='mu-', help="gun particle type, e.g. e-, e+, gamma, mu-, pi0 etc.")
+    p.add_argument('--gun_energy', default=100, type=float, help="gun particle energy in GeV")
+    p.add_argument('--gun_position', nargs=3, type=float, default=[0, 0, 0], help="gun position in meters")
+    p.add_argument('--gun_direction', nargs=3, type=float, default=[0, 0, 1], help="gun direction X, Y, Z components")
     p.add_argument('--gps_macro', default='muons.mac', help="macro files with Geant4 GPS commands to congigure particle source")
     p.add_argument('--skip_min', default=0.002, help="minimal of particle energy to skip")
     p.add_argument('--skip_max', default=0.01, help="maximal of particle energy to skip")
@@ -54,7 +59,7 @@ def run(app, n_events=10, ofname="output.h5"):
         h5file = h5py.File(ofname, "a")
         g = h5file.create_group(f"event_{ievt}")
         g.create_dataset('photons', 
-                         data = np.array( [tuple(row) for row in data.photon_cloud],
+                         data = np.array( [tuple(row) for row in data.photons],
                                           dtype = [('x_m', float), ('y_m', float), ('z_m', float),
                                                    ('t_ns', float),
                                                    ('dx', float), ('dy', float), ('dz', float),
@@ -79,24 +84,25 @@ def run(app, n_events=10, ofname="output.h5"):
         log.info(f"   Number of particles:     {len(data.particles)}")
         log.info(f"   Number of tracks:       {len(np.unique(data.tracks[:,0]))}")
         log.info(f"   Number of track points: {len(data.tracks)}")
-        log.info(f"   Number of photons:      {len(data.photon_cloud)}")
+        log.info(f"   Number of photons:      {len(data.photons)}")
         db = app.data_buffer
-        #log.info(f"   Number of particles / tracks points / photons : {len(db.particles):6.0f} / {len(db.tracks):6.0f} / {len(db.photon_cloud):6.0f}")
+        #log.info(f"   Number of particles / tracks points / photons : {len(db.particles):6.0f} / {len(db.tracks):6.0f} / {len(db.photons):6.0f}")
         log.info(" ")
 
 
 def main():
     opts = parse_arguments()
+    physics = opts.physics
     optics = opts.enable_optics
     #
     if opts.primary_generator == 'gun':
-        gun_args = {'particle': 'mu-', 
-                    'energy_GeV': 1, 
-                    'position_m': [0,0,0],
-                    'direction': [0,0,1]}
-        app = g4camp(optics=optics, primary_generator='gun', gun_args=gun_args)
+        gun_args = {'particle': opts.gun_particle, 
+                    'energy_GeV': opts.gun_energy, 
+                    'position_m': opts.gun_position,
+                    'direction': opts.gun_direction}
+        app = g4camp(physics=physics, optics=optics, primary_generator='gun', gun_args=gun_args)
     elif opts.primary_generator == 'gps':
-        app = g4camp(optics=optics, primary_generator='gps')
+        app = g4camp(physics=physics, optics=optics, primary_generator='gps')
         app.setGPSMacro(opts.gps_macro)
     else:
         log.error(f"Wrong primary type '{opts.primary_generator}'")
@@ -105,9 +111,10 @@ def main():
     app.setSkipMinMax(float(opts.skip_min), float(opts.skip_max))
     app.setPhotonSuppressionFactor(float(opts.photon_suppression))
     app.setDetectorHeight(opts.det_height)
-    app.setDetectorRaduis(opts.det_radius)
+    app.setDetectorRadius(opts.det_radius)
     app.configure()
     run(app, n_events=int(opts.n), ofname=opts.o)
+    log.info("All done!")
 
 
 if __name__ == "__main__":
